@@ -9,14 +9,12 @@ mod test;
 
 use crate::{
     basic::mapx_oc::{self, MapxOC, MapxOCIter},
-    common::{MetaInfo, SimpleVisitor},
+    common::{InstanceCfg, SimpleVisitor},
 };
 use ruc::*;
 use serde::{de::DeserializeOwned, Serialize};
 use std::{
-    cmp::Ordering,
     fmt,
-    iter::{DoubleEndedIterator, Iterator},
     marker::PhantomData,
     mem::ManuallyDrop,
     ops::{Deref, DerefMut},
@@ -24,7 +22,7 @@ use std::{
 
 /// To solve the problem of unlimited memory usage,
 /// use this to replace the original in-memory `BTreeMap<_, _>`.
-#[derive(PartialEq, Eq, PartialOrd, Ord, Debug, Clone)]
+#[derive(PartialEq, Eq, Debug)]
 pub struct Mapx<K, V>
 where
     K: Clone
@@ -35,7 +33,7 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     inner: MapxOC<Vec<u8>, V>,
     _pd: PhantomData<K>,
@@ -51,7 +49,7 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     fn default() -> Self {
         Self::new()
@@ -59,12 +57,8 @@ where
 }
 
 macro_rules! convert {
-    ($as_param: expr) => {{
-        bincode::serialize::<K>($as_param).unwrap()
-    }};
-    (@$as_ret: expr) => {{
-        bincode::deserialize::<K>(&$as_ret).unwrap()
-    }};
+    ($as_param: expr) => {{ bcs::to_bytes::<K>($as_param).unwrap() }};
+    (@$as_ret: expr) => {{ bcs::from_bytes::<K>(&$as_ret).unwrap() }};
 }
 
 ///////////////////////////////////////////////
@@ -81,7 +75,7 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     /// Create an instance.
     #[inline(always)]
@@ -93,13 +87,11 @@ where
     }
 
     // Get the database storage path
-    fn get_meta(&self) -> MetaInfo {
-        self.inner.get_meta()
+    fn get_instance_cfg(&self) -> InstanceCfg {
+        self.inner.get_instance_cfg()
     }
 
     /// Imitate the behavior of 'BTreeMap<_>.get(...)'
-    ///
-    /// Any faster/better choice other than JSON ?
     #[inline(always)]
     pub fn get(&self, key: &K) -> Option<V> {
         self.inner.get(&convert!(key))
@@ -126,17 +118,6 @@ where
         self.inner.is_empty()
     }
 
-    ///
-    /// # Safety
-    ///
-    /// Only make sense after a 'DataBase clear',
-    /// do NOT use this function except testing.
-    ///
-    #[inline(always)]
-    pub unsafe fn set_len(&mut self, len: u64) {
-        self.inner.set_len(len);
-    }
-
     /// Imitate the behavior of 'BTreeMap<_>.insert(...)'.
     #[inline(always)]
     pub fn insert(&mut self, key: K, value: V) -> Option<V> {
@@ -187,6 +168,12 @@ where
         let key = convert!(key);
         self.inner.unset_value(&key);
     }
+
+    /// Clear all data.
+    #[inline(always)]
+    pub fn clear(&mut self) {
+        self.inner.clear();
+    }
 }
 
 /*******************************************/
@@ -209,7 +196,7 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     hdr: &'a mut Mapx<K, V>,
     key: ManuallyDrop<K>,
@@ -226,7 +213,7 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     fn new(hdr: &'a mut Mapx<K, V>, key: K, value: V) -> Self {
         ValueMut {
@@ -235,16 +222,9 @@ where
             value: ManuallyDrop::new(value),
         }
     }
-
-    /// Clone the inner value.
-    pub fn clone_inner(self) -> V {
-        ManuallyDrop::into_inner(self.value.clone())
-    }
 }
 
-///
-/// **NOTE**: VERY IMPORTANT !!!
-///
+/// NOTE: Very Important !!!
 impl<'a, K, V> Drop for ValueMut<'a, K, V>
 where
     K: Clone
@@ -255,7 +235,7 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     fn drop(&mut self) {
         // This operation is safe within a `drop()`.
@@ -279,7 +259,7 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     type Target = V;
 
@@ -298,64 +278,13 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     fn deref_mut(&mut self) -> &mut Self::Target {
         &mut self.value
     }
 }
 
-impl<'a, K, V> PartialEq for ValueMut<'a, K, V>
-where
-    K: Clone
-        + PartialEq
-        + Eq
-        + PartialOrd
-        + Ord
-        + Serialize
-        + DeserializeOwned
-        + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
-{
-    fn eq(&self, other: &ValueMut<'a, K, V>) -> bool {
-        self.value == other.value
-    }
-}
-
-impl<'a, K, V> PartialEq<V> for ValueMut<'a, K, V>
-where
-    K: Clone
-        + PartialEq
-        + Eq
-        + PartialOrd
-        + Ord
-        + Serialize
-        + DeserializeOwned
-        + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
-{
-    fn eq(&self, other: &V) -> bool {
-        self.value.deref() == other
-    }
-}
-
-impl<'a, K, V> PartialOrd<V> for ValueMut<'a, K, V>
-where
-    K: Clone
-        + PartialEq
-        + Eq
-        + PartialOrd
-        + Ord
-        + Serialize
-        + DeserializeOwned
-        + fmt::Debug,
-    V: Clone + PartialEq + Ord + PartialOrd + Serialize + DeserializeOwned + fmt::Debug,
-{
-    fn partial_cmp(&self, other: &V) -> Option<Ordering> {
-        self.value.deref().partial_cmp(other)
-    }
-}
-
 /******************************************************************************/
 // End of the implementation of ValueMut(returned by `self.get_mut`) for Mapx //
 ////////////////////////////////////////////////////////////////////////////////
@@ -367,8 +296,8 @@ where
 /// Iter over [Mapx](self::Mapx).
 pub struct MapxIter<K, V>
 where
-    K: Clone + PartialEq + Eq + Serialize + DeserializeOwned + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    K: PartialEq + Eq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     iter: MapxOCIter<Vec<u8>, V>,
     _pd: PhantomData<K>,
@@ -376,8 +305,8 @@ where
 
 impl<K, V> Iterator for MapxIter<K, V>
 where
-    K: Clone + PartialEq + Eq + Serialize + DeserializeOwned + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    K: PartialEq + Eq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     type Item = (K, V);
     fn next(&mut self) -> Option<Self::Item> {
@@ -387,8 +316,8 @@ where
 
 impl<K, V> DoubleEndedIterator for MapxIter<K, V>
 where
-    K: Clone + PartialEq + Eq + Serialize + DeserializeOwned + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    K: PartialEq + Eq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     fn next_back(&mut self) -> Option<Self::Item> {
         self.iter.next_back().map(|(k, v)| (convert!(@k), v))
@@ -413,13 +342,13 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     fn serialize<S>(&self, serializer: S) -> std::result::Result<S::Ok, S::Error>
     where
         S: serde::Serializer,
     {
-        let v = pnk!(bincode::serialize(&self.get_meta()));
+        let v = pnk!(bcs::to_bytes(&self.get_instance_cfg()));
         serializer.serialize_bytes(&v)
     }
 }
@@ -434,14 +363,14 @@ where
         + Serialize
         + DeserializeOwned
         + fmt::Debug,
-    V: Clone + PartialEq + Serialize + DeserializeOwned + fmt::Debug,
+    V: Serialize + DeserializeOwned + fmt::Debug,
 {
     fn deserialize<D>(deserializer: D) -> std::result::Result<Self, D::Error>
     where
         D: serde::Deserializer<'de>,
     {
         deserializer.deserialize_bytes(SimpleVisitor).map(|meta| {
-            let meta = pnk!(bincode::deserialize::<MetaInfo>(&meta));
+            let meta = pnk!(bcs::from_bytes::<InstanceCfg>(&meta));
             Mapx {
                 inner: MapxOC::from(meta),
                 _pd: PhantomData,
