@@ -1,7 +1,3 @@
-//!
-//! # Test Cases
-//!
-
 use super::*;
 use serde::{Deserialize, Serialize};
 
@@ -19,36 +15,34 @@ fn gen_sample(idx: usize) -> SampleBlock {
 }
 
 #[test]
-fn t_mapx() {
-    crate::vsdb_clear();
-
+fn basic_cases() {
     let cnt = 200;
 
-    let db = {
-        let mut dbi = crate::Mapx::new();
+    let hdr = {
+        let mut hdr_i = crate::Mapx::new();
 
-        assert_eq!(0, dbi.len());
+        assert_eq!(0, hdr_i.len());
         (0..cnt).for_each(|i| {
-            assert!(dbi.get(&i).is_none());
+            assert!(hdr_i.get(&i).is_none());
         });
 
         (0..cnt).map(|i| (i, gen_sample(i))).for_each(|(i, b)| {
-            dbi.entry(i).or_insert(b.clone());
-            assert_eq!(1 + i as usize, dbi.len());
-            assert_eq!(pnk!(dbi.get(&i)).idx, i);
-            assert_eq!(dbi.remove(&i), Some(b.clone()));
-            assert_eq!(i as usize, dbi.len());
-            assert!(dbi.get(&i).is_none());
-            assert!(dbi.insert(i, b.clone()).is_none());
-            assert!(dbi.insert(i, b).is_some());
+            hdr_i.entry(i).or_insert(b.clone());
+            assert_eq!(1 + i as usize, hdr_i.len());
+            assert_eq!(pnk!(hdr_i.get(&i)).idx, i);
+            assert_eq!(hdr_i.remove(&i), Some(b.clone()));
+            assert_eq!(i as usize, hdr_i.len());
+            assert!(hdr_i.get(&i).is_none());
+            assert!(hdr_i.insert(i, b.clone()).is_none());
+            assert!(hdr_i.insert(i, b).is_some());
         });
 
-        assert_eq!(cnt, dbi.len());
+        assert_eq!(cnt, hdr_i.len());
 
-        pnk!(bincode::serialize(&dbi))
+        pnk!(bcs::to_bytes(&hdr_i))
     };
 
-    let mut reloaded = pnk!(bincode::deserialize::<Mapx<usize, SampleBlock>>(&db));
+    let mut reloaded = pnk!(bcs::from_bytes::<Mapx<usize, SampleBlock>>(&hdr));
 
     assert_eq!(cnt, reloaded.len());
 
@@ -65,7 +59,6 @@ fn t_mapx() {
     });
 
     assert_eq!(1, reloaded.len());
-    crate::vsdb_clear();
-    unsafe { reloaded.set_len(0) };
+    reloaded.clear();
     assert!(reloaded.is_empty());
 }
