@@ -8,26 +8,25 @@ mod backend;
 #[cfg(test)]
 mod test;
 
-use crate::common::{MetaInfo, SimpleVisitor, VSDB};
+use crate::common::{InstanceCfg, SimpleVisitor, VSDB};
 use ruc::*;
 use sled::IVec;
 use std::{
-    iter::Iterator,
     mem::ManuallyDrop,
     ops::{Deref, DerefMut, RangeBounds},
 };
 
 /// To solve the problem of unlimited memory usage,
 /// use this to replace the original in-memory `BTreeMap<_, _>`.
-#[derive(PartialEq, Eq, PartialOrd, Ord, Debug, Clone)]
+#[derive(PartialEq, Eq, Debug)]
 pub struct MapxRaw {
-    in_disk: backend::MapxRaw,
+    inner: backend::MapxRaw,
 }
 
-impl From<MetaInfo> for MapxRaw {
-    fn from(mi: MetaInfo) -> Self {
+impl From<InstanceCfg> for MapxRaw {
+    fn from(cfg: InstanceCfg) -> Self {
         Self {
-            in_disk: backend::MapxRaw::from(mi),
+            inner: backend::MapxRaw::from(cfg),
         }
     }
 }
@@ -47,39 +46,37 @@ impl MapxRaw {
     #[inline(always)]
     pub fn new() -> Self {
         MapxRaw {
-            in_disk: backend::MapxRaw::must_new(VSDB.alloc_id()),
+            inner: backend::MapxRaw::must_new(VSDB.alloc_prefix()),
         }
     }
 
     // Get the database storage path
-    pub(crate) fn get_meta(&self) -> MetaInfo {
-        self.in_disk.get_meta()
+    pub(crate) fn get_instance_cfg(&self) -> InstanceCfg {
+        self.inner.get_instance_cfg()
     }
 
     /// Imitate the behavior of 'BTreeMap<_>.get(...)'
-    ///
-    /// Any faster/better choice other than JSON ?
     #[inline(always)]
     pub fn get(&self, key: &[u8]) -> Option<IVec> {
-        self.in_disk.get(key)
+        self.inner.get(key)
     }
 
     /// less or equal value
     #[inline(always)]
     pub fn get_le(&self, key: &[u8]) -> Option<(IVec, IVec)> {
-        self.in_disk.get_le(key)
+        self.inner.get_le(key)
     }
 
     /// great or equal value
     #[inline(always)]
     pub fn get_ge(&self, key: &[u8]) -> Option<(IVec, IVec)> {
-        self.in_disk.get_ge(key)
+        self.inner.get_ge(key)
     }
 
     /// Imitate the behavior of 'BTreeMap<_>.get_mut(...)'
     #[inline(always)]
     pub fn get_mut(&mut self, key: &[u8]) -> Option<ValueMut<'_>> {
-        self.in_disk
+        self.inner
             .get(key)
             .map(move |v| ValueMut::new(self, IVec::from(key), v))
     }
@@ -87,43 +84,32 @@ impl MapxRaw {
     /// Imitate the behavior of 'BTreeMap<_>.len()'.
     #[inline(always)]
     pub fn len(&self) -> usize {
-        self.in_disk.len()
+        self.inner.len()
     }
 
     /// A helper func
     #[inline(always)]
     pub fn is_empty(&self) -> bool {
-        self.in_disk.is_empty()
-    }
-
-    ///
-    /// # Safety
-    ///
-    /// Only make sense after a 'DataBase clear',
-    /// do NOT use this function except testing.
-    ///
-    #[inline(always)]
-    pub unsafe fn set_len(&mut self, len: u64) {
-        self.in_disk.set_len(len);
+        self.inner.is_empty()
     }
 
     /// Imitate the behavior of 'BTreeMap<_>.insert(...)'.
     #[inline(always)]
     pub fn insert(&mut self, key: &[u8], value: &[u8]) -> Option<IVec> {
-        self.in_disk.insert(key, value)
+        self.inner.insert(key, value)
     }
 
     /// Imitate the behavior of '.entry(...).or_insert(...)'
     #[inline(always)]
     pub fn entry<'a>(&'a mut self, key: &'a [u8]) -> Entry<'a> {
-        Entry { key, db: self }
+        Entry { key, hdr: self }
     }
 
     /// Imitate the behavior of '.iter()'
     #[inline(always)]
     pub fn iter(&self) -> MapxRawIter {
         MapxRawIter {
-            iter: self.in_disk.iter(),
+            iter: self.inner.iter(),
         }
     }
 
@@ -131,20 +117,26 @@ impl MapxRaw {
     #[inline(always)]
     pub fn range<'a, R: RangeBounds<&'a [u8]>>(&'a self, bounds: R) -> MapxRawIter {
         MapxRawIter {
-            iter: self.in_disk.range(bounds),
+            iter: self.inner.range(bounds),
         }
     }
 
     /// Check if a key is exists.
     #[inline(always)]
     pub fn contains_key(&self, key: &[u8]) -> bool {
-        self.in_disk.contains_key(key)
+        self.inner.contains_key(key)
     }
 
     /// Try to remove an entry
     #[inline(always)]
     pub fn remove(&mut self, key: &[u8]) -> Option<IVec> {
-        self.in_disk.remove(key)
+        self.inner.remove(key)
+    }
+
+    /// Clear all data.
+    #[inline(always)]
+    pub fn clear(&mut self) {
+        self.inner.clear();
     }
 }
 
@@ -157,7 +149,7 @@ impl MapxRaw {
 /********************************************************************************/
 
 /// Returned by `<MapxRaw>.get_mut(...)`
-#[derive(PartialEq, Eq, PartialOrd, Ord, Debug)]
+#[derive(PartialEq, Eq, Debug)]
 pub struct ValueMut<'a> {
     hdr: &'a mut MapxRaw,
     key: ManuallyDrop<IVec>,
@@ -172,16 +164,9 @@ impl<'a> ValueMut<'a> {
             value: ManuallyDrop::new(value),
         }
     }
-
-    /// Take the inner value.
-    pub fn clone_inner(self) -> IVec {
-        ManuallyDrop::into_inner(self.value.clone())
-    }
 }
 
-///
-/// **NOTE**: &[u8]ERY IMPORTANT !!!
-///
+/// NOTE: Very Important !!!
 impl<'a> Drop for ValueMut<'a> {
     fn drop(&mut self) {
         // This operation is safe within a `drop()`.
@@ -220,16 +205,16 @@ impl<'a> DerefMut for ValueMut<'a> {
 /// Imitate the `btree_map/btree_map::Entry`.
 pub struct Entry<'a> {
     key: &'a [u8],
-    db: &'a mut MapxRaw,
+    hdr: &'a mut MapxRaw,
 }
 
 impl<'a> Entry<'a> {
     /// Imitate the `btree_map/btree_map::Entry.or_insert(...)`.
     pub fn or_insert(self, default: &'a [u8]) -> ValueMut<'a> {
-        if !self.db.contains_key(self.key) {
-            self.db.insert(self.key, default);
+        if !self.hdr.contains_key(self.key) {
+            self.hdr.insert(self.key, default);
         }
-        pnk!(self.db.get_mut(self.key))
+        pnk!(self.hdr.get_mut(self.key))
     }
 
     /// Imitate the `btree_map/btree_map::Entry.or_insert_with(...)`.
@@ -237,10 +222,10 @@ impl<'a> Entry<'a> {
     where
         F: FnOnce() -> Vec<u8>,
     {
-        if !self.db.contains_key(self.key) {
-            self.db.insert(self.key, &default());
+        if !self.hdr.contains_key(self.key) {
+            self.hdr.insert(self.key, &default());
         }
-        pnk!(self.db.get_mut(self.key))
+        pnk!(self.hdr.get_mut(self.key))
     }
 }
 
@@ -283,7 +268,7 @@ impl serde::Serialize for MapxRaw {
     where
         S: serde::Serializer,
     {
-        let v = pnk!(bincode::serialize(&self.get_meta()));
+        let v = pnk!(bcs::to_bytes(&self.get_instance_cfg()));
         serializer.serialize_bytes(&v)
     }
 }
@@ -294,7 +279,7 @@ impl<'de> serde::Deserialize<'de> for MapxRaw {
         D: serde::Deserializer<'de>,
     {
         deserializer.deserialize_bytes(SimpleVisitor).map(|meta| {
-            let meta = pnk!(bincode::deserialize::<MetaInfo>(&meta));
+            let meta = pnk!(bcs::from_bytes::<InstanceCfg>(&meta));
             MapxRaw::from(meta)
         })
     }
